@@ -1,4 +1,4 @@
-//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.8/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.9/mozilla/toolkit/mozapps/downloads/content/downloads.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -752,8 +752,15 @@ function initAutoDownloadDisplay()
 
     function getSpecialFolderKey(aFolderType) 
     {
-//@line 807 "/usr/obj/ports/mozilla-firefox-1.5.0.8/mozilla/toolkit/mozapps/downloads/content/downloads.js"
-      return "Home";
+    if (aFolderType == "Desktop")
+      return "Desk";
+
+    if (aFolderType != "Downloads")
+      throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
+
+//@line 807 "/usr/obj/ports/mozilla-firefox-1.5.0.9/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+    return "Home";
+//@line 810 "/usr/obj/ports/mozilla-firefox-1.5.0.9/mozilla/toolkit/mozapps/downloads/content/downloads.js"
     }
     
     function getDownloadsFolder(aFolder)
